@@ -9,7 +9,7 @@
 void lasso_ladm_scr(double *XY0, double *Xy, double *X0, double *X, double *XX0, double *XX, int *idx_scr, int num_scr, int ndata, int dim, double *beta, double *T, double rho, int *ite, double lambda, int max_ite, double prec, int intercept, int flag, int nlamb)
 {
     int j,k,m,w_idx,size_a,size_a1,size_a_pre;
-    double gap_ext,max_dif,beta_dif,threshold,tmpd,ratio,epsT;
+    double gap_ext,max_dif,beta_dif,threshold,tmpd;
     int * idx_tmp;
     
     
@@ -26,8 +26,6 @@ void lasso_ladm_scr(double *XY0, double *Xy, double *X0, double *X, double *XX0,
     double *y_i = (double*) malloc(ndata*sizeof(double));
     double *g = (double*) malloc(num_scr*sizeof(double));
     double *r = (double*) malloc(ndata*sizeof(double));
-    ratio = 0.5;
-    epsT = 1e1;
     //stop = clock();
     //time1 += stop - start;
     
@@ -180,7 +178,7 @@ void lasso_ladm_scr(double *XY0, double *Xy, double *X0, double *X, double *XX0,
 void slim_lasso_ladm_scr(double *XY0, double *X0, double *XX, double *beta, int *n, int *d, int *ite_int, int *ite_int1, int *ite_int2, int *num_scr_1, int *num_scr_2, int *idx_scr, int * idx_scr_1, int * idx_scr_2, double * gamma, double * lambda, int * nnlambda, int *max_ite, double *prec, int * intercept)
 {
     int j,k,m,ndata,dim,nlambda,ite1,ite2,ite,max_ite0,max_ite1,max_ite2,num_scr,num_scr1,num_scr2,num_scr1_tmp,num_scr2_tmp,flag,flag1,flag2;
-    double T,T1,T2,rho,zero,eps,eps1,eps2,ilambda;
+    double T,T1,T2,rho,eps,eps1,eps2,ilambda;
     
     //time0 = 0;
     //time1 = 0;
@@ -201,7 +199,6 @@ void slim_lasso_ladm_scr(double *XY0, double *X0, double *XX, double *beta, int
     eps1 = *prec;
     eps2 = *prec;
     eps = eps2*10;
-    zero = 0;
 
     
     double *beta0 = (double*) malloc(dim*sizeof(double));
@@ -293,4 +290,3 @@ void slim_lasso_ladm_scr(double *XY0, double *X0, double *XX, double *beta, int
     free(XX1);
     free(XX2);
 }
-
