@@ -239,7 +239,7 @@ void lq_ladm_scr_btr(double *Y0, double *X0, double *X, double *XX0, double *XX,
 void slim_lq_ladm_scr_btr(double *Y0, double *X0, double *XX, double *beta, int *n, int *d, double *rho0, int *ite_int, int *ite_int1, int *ite_int2, int *num_scr_1, int *num_scr_2, int *idx_scr, int * idx_scr_1, int * idx_scr_2, double * gamma, double * lambda, int * nnlambda, int *max_ite, double *prec, int * intercept, double *q)
 {
     int j,k,m,ndata,dim,nlambda,ite1,ite2,ite,max_ite0,max_ite1,max_ite2,num_scr,num_scr1,num_scr2,num_scr1_tmp,num_scr2_tmp,flag,flag1,flag2;
-    double T,T1,T2,rho,zero,eps,eps1,eps2,ilambda,nrholamb,qrtn;
+    double T,T1,T2,rho,eps,eps1,eps2,ilambda,nrholamb,qrtn;
     
     //time0 = 0;
     //time1 = 0;
@@ -261,7 +261,6 @@ void slim_lq_ladm_scr_btr(double *Y0, double *X0, double *XX, double *beta, int
     eps1 = *prec;
     eps2 = *prec;
     eps = eps2*10;
-    zero = 0;
     qrtn = pow((double) ndata,1/(*q));
 
     
@@ -359,4 +358,3 @@ void slim_lq_ladm_scr_btr(double *Y0, double *X0, double *XX, double *beta, int
     free(XX1);
     free(XX2);
 }
-
