@@ -9,7 +9,7 @@
 void sqrt_ladm_scr(double *Y0, double *X0, double *X, double *XX0, double *XX, int *idx_scr, int num_scr, int ndata, int dim, double *alp, double *beta, double * mu, double *T, double rho, int *ite, double lambda, int max_ite, double prec, int intercept, int flag, int nlamb, double nrholamb)
 {
     int j,k,m,w_idx,size_a,size_a1,size_a_pre;
-    double gap_ext,max_dif,alp_dif,beta_dif,mu_dif,threshold,tmpd,alp_tild_sq,alp_th,ratio,epsT;
+    double gap_ext,max_dif,alp_dif,beta_dif,mu_dif,threshold,tmpd,alp_tild_sq,alp_th;
     int * idx_tmp;
     
     
@@ -34,8 +34,6 @@ void sqrt_ladm_scr(double *Y0, double *X0, double *X, double *XX0, double *XX, i
     double *r = (double*) malloc(ndata*sizeof(double));
     //double *X = (double*) malloc(num_scr*num_scr*sizeof(double));
     //double *Y = (double*) malloc(num_scr*sizeof(double));
-    ratio = 0.5;
-    epsT = 1e1;
     //stop = clock();
     //time1 += stop - start;
     
@@ -282,7 +280,7 @@ void sqrt_ladm_scr(double *Y0, double *X0, double *X, double *XX0, double *XX, i
 void slim_sqrt_ladm_scr(double *Y0, double *X0, double *XX, double *beta, int *n, int *d, double *rho0, int *ite_int, int *ite_int1, int *ite_int2, int *num_scr_1, int *num_scr_2, int *idx_scr, int * idx_scr_1, int * idx_scr_2, double * gamma, double * lambda, int * nnlambda, int *max_ite, double *prec, int * intercept)
 {
     int j,k,m,ndata,dim,nlambda,ite1,ite2,ite,max_ite0,max_ite1,max_ite2,num_scr,num_scr1,num_scr2,num_scr1_tmp,num_scr2_tmp,flag,flag1,flag2;
-    double T,T1,T2,rho,zero,eps,eps1,eps2,ilambda,sqrtn,nrholamb;
+    double T,T1,T2,rho,eps,eps1,eps2,ilambda,sqrtn,nrholamb;
     
     //time0 = 0;
     //time1 = 0;
@@ -304,7 +302,6 @@ void slim_sqrt_ladm_scr(double *Y0, double *X0, double *XX, double *beta, int *n
     eps1 = *prec;
     eps2 = *prec;
     eps = eps2*10;
-    zero = 0;
     sqrtn = sqrt((double) ndata);
 
     
@@ -429,4 +426,3 @@ void slim_sqrt_ladm_scr(double *Y0, double *X0, double *XX, double *beta, int *n
     free(XX1);
     free(XX2);
 }
-
